@@ -31,7 +31,7 @@
 #'
 #' #Search for Hypertension and Stroke ICD codes and summarize per patient providing earliest time
 #' diseases <- list(HT = c("ICD10:I10"), Stroke = c("ICD9:434.91", "ICD9:I63.50"))
-#' data_enc_disease <-  convert_dia(d = data_dia, codes_to_find = diseases,
+#' data_dia_disease <-  convert_dia(d = data_dia, codes_to_find = diseases,
 #' nThread = 2, collapse = "ID_MERGE", time_type = "earliest")
 #' }
 
@@ -41,7 +41,7 @@ convert_dia <- function(d, code = "dia_code", code_type = "dia_code_type",  code
   .SD=.N=.I=.GRP=.BY=.EACHI=..=..cols=.SDcols=i=j=time_to_db=..which_ids_to=..which_ids_from=combined=..collapse=. <- NULL
 
   #Initialize multicore
-  if(nThread == 1) {
+  if(nThread == 1 | length(codes_to_find) == 1) {
     `%exec%` <- foreach::`%do%`
   } else {
     if(length(codes_to_find) > 0 & length(codes_to_find) < nThread) {nThread <- length(codes_to_find)}
